@@ -1,4 +1,8 @@
 from detech_query_pkg import dynamodb_queries as db
+from detech_query_pkg.utils import dynamodb_utils as utils
+
+from boto3.dynamodb.conditions import Key
+
 import boto3
 from datetime import datetime
 import time
@@ -22,7 +26,10 @@ db.create_metric(
   first = int(time.time()-100), last = int(time.time()), data_points_list = [], dynamodb=dynamodb
 )'''
 
-a = db.query_most_recent_metric_fetching_log('prd_db', dynamodb)
-print(a)
+#a = db.query_most_recent_metric_fetching_log('prd_db', dynamodb)
+#print(a)
 #a = db.query_most_recent_metric_fetching_log('prd_db_2', dynamodb)
-#print(a['last_fetched_ts'])
\ No newline at end of file
+#print(a['last_fetched_ts'])
+
+key_condition = Key('component_id').eq('prd_db')
+print(utils.query_by_key_min_max(key_condition, 'logs.cloud_metric_fetching', False, dynamodb))
\ No newline at end of file
